==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomLocale.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomLocale</code></p>
 */
public class DomLocale extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomLocale::<wbr/>DomLocale()</code></p>
     */
    public DomLocale(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLocale instance);
    
    /**
     * <p>See <code>DomLocale::<wbr/>attributeCountry()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeCountry(){
        return attributeCountry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeCountry_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>attributeLanguage()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeLanguage(){
        return attributeLanguage_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeLanguage_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>clearAttributeCountry()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeCountry(){
        clearAttributeCountry_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeCountry_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>clearAttributeLanguage()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeLanguage(){
        clearAttributeLanguage_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeLanguage_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>hasAttributeCountry()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeCountry(){
        return hasAttributeCountry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeCountry_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>hasAttributeLanguage()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeLanguage(){
        return hasAttributeLanguage_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeLanguage_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomLocale::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomLocale::<wbr/>setAttributeCountry(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeCountry(java.lang.@NonNull String a){
        setAttributeCountry_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeCountry_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomLocale::<wbr/>setAttributeLanguage(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeLanguage(java.lang.@NonNull String a){
        setAttributeLanguage_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeLanguage_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomLocale::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomLocale(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.12-sources.jar: io/qt/uic/ui4/DomLocale.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomLocale</p>
 */
public class DomLocale extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomLocale(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomLocale instance);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeCountry(){
        return attributeCountry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeCountry_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeLanguage(){
        return attributeLanguage_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeLanguage_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeCountry(){
        clearAttributeCountry_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeCountry_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeLanguage(){
        clearAttributeLanguage_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeLanguage_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeCountry(){
        return hasAttributeCountry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeCountry_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeLanguage(){
        return hasAttributeLanguage_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeLanguage_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setAttributeCountry(java.lang.@NonNull String a){
        setAttributeCountry_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeCountry_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @QtUninvokable
    public final void setAttributeLanguage(java.lang.@NonNull String a){
        setAttributeLanguage_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeLanguage_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomLocale(QPrivateConstructor p) { super(p); } 
    
}
